==> ui-18.1.1.tgz: package/components/input/Input.js <==
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import { isUndefined } from 'lodash';
import { useMemo, useRef, useState } from 'react';
import { Subject, fromEvent, takeUntil, first } from 'rxjs';
import { useAsync, useForceUpdate, useForkRef, useUnmount } from '@react-devui/hooks';
import { CloseCircleFilled, DCustomIcon, EyeInvisibleOutlined, EyeOutlined } from '@react-devui/icons';
import { checkNodeExist, getClassName } from '@react-devui/utils';
import { useGeneralContext, useDValue } from '../../hooks';
import { registerComponentMate } from '../../utils';
import { DBaseDesign } from '../_base-design';
import { DBaseInput } from '../_base-input';
import { useFormControl } from '../form';
import { useComponentConfig, usePrefixConfig, useTranslation } from '../root';
const { COMPONENT_NAME } = registerComponentMate({ COMPONENT_NAME: 'DInput' });
export function DInput(props) {
    const _a = useComponentConfig(COMPONENT_NAME, props), { dRef, dFormControl, dModel, dType, dPrefix: dPrefixNode, dSuffix, dPassword, dNumbetButton = true, dClearable = false, dSize, dMax, dMin, dStep, dInteger = false, dPlaceholder, dDisabled = false, dInputRender, onModelChange, onClear, onPasswordChange } = _a, restProps = __rest(_a, ["dRef", "dFormControl", "dModel", "dType", "dPrefix", "dSuffix", "dPassword", "dNumbetButton", "dClearable", "dSize", "dMax", "dMin", "dStep", "dInteger", "dPlaceholder", "dDisabled", "dInputRender", "onModelChange", "onClear", "onPasswordChange"]);
    //#region Context
    const dPrefix = usePrefixConfig();
    const { gSize, gDisabled } = useGeneralContext();
    //#endregion
    //#region Ref
    const inputRef = useRef(null);
    const combineInputRef = useForkRef(inputRef, dRef === null || dRef === void 0 ? void 0 : dRef.input);
    //#endregion
    const dataRef = useRef({
        showValue: '',
        prevValue: '',
    });
    const async = useAsync();
    const [t] = useTranslation();
    const forceUpdate = useForceUpdate();
    const [password, changePassword] = useDValue(true, dPassword, onPasswordChange);
    const onDestroy$ = useMemo(() => new Subject(), []);
    const formControlInject = useFormControl(dFormControl);
    const [_value, changeValue] = useDValue('', dModel, onModelChange, undefined, formControlInject);
    if (_value !== dataRef.current.prevValue) {
        dataRef.current.showValue = dataRef.current.prevValue = _value;
    }
    const [isFocus, setIsFocus] = useState(false);
    const size = dSize !== null && dSize !== void 0 ? dSize : gSize;
    const disabled = dDisabled || gDisabled || (dFormControl === null || dFormControl === void 0 ? void 0 : dFormControl.control.disabled);
    const changeNumber = (isIncrease = true) => {
        var _a, _b;
        const stepVal = dStep !== null && dStep !== void 0 ? dStep : 1;
        const newVal = (() => {
            let val = Number(dataRef.current.showValue);
            if (Number.isNaN(val)) {
                return 0;
            }
            if (dInteger && !Number.isInteger(val)) {
                val = Math.round(val);
            }
            return isIncrease ? val + stepVal : val - stepVal;
        })();
        changeValue(Math.max(dMin !== null && dMin !== void 0 ? dMin : -Infinity, Math.min(dMax !== null && dMax !== void 0 ? dMax : Infinity, newVal)).toFixed((_b = (_a = stepVal.toString().split('.')[1]) === null || _a === void 0 ? void 0 : _a.length) !== null && _b !== void 0 ? _b : 0));
    };
    const handleNumberMouseUp = () => {
        var _a, _b, _c, _d;
        (_b = (_a = dataRef.current).clearLoop) === null || _b === void 0 ? void 0 : _b.call(_a);
        (_d = (_c = dataRef.current).clearTid) === null || _d === void 0 ? void 0 : _d.call(_c);
    };
    const handleNumberMouseDown = (isIncrease = true) => {
        const loop = () => {
            changeNumber(isIncrease);
            dataRef.current.clearLoop = async.setTimeout(() => loop(), 50);
        };
        dataRef.current.clearTid = async.setTimeout(() => loop(), 400);
        fromEvent(window, 'mouseup')
            .pipe(takeUntil(onDestroy$), first())
            .subscribe({
            next: () => {
                handleNumberMouseUp();
            },
        });
    };
    const preventBlur = (e) => {
        if (e.target !== inputRef.current && e.button === 0) {
            e.preventDefault();
        }
    };
    useUnmount(() => {
        handleNumberMouseUp();
        onDestroy$.next();
        onDestroy$.complete();
    });
    return (_jsx(DBaseDesign, Object.assign({ dComposeDesign: {
            active: isFocus,
            disabled: disabled,
        }, dFormDesign: {
            control: dFormControl,
        } }, { children: ({ render: renderBaseDesign }) => renderBaseDesign(_jsxs("div", Object.assign({}, restProps, { className: getClassName(restProps.className, `${dPrefix}input`, {
                [`${dPrefix}input--${size}`]: size,
                [`${dPrefix}input--number`]: dType === 'number',
                'is-disabled': disabled,
                'is-focus': isFocus,
            }), onMouseDown: (e) => {
                var _a;
                (_a = restProps.onMouseDown) === null || _a === void 0 ? void 0 : _a.call(restProps, e);
                preventBlur(e);
            }, onMouseUp: (e) => {
                var _a;
                (_a = restProps.onMouseUp) === null || _a === void 0 ? void 0 : _a.call(restProps, e);
                preventBlur(e);
            }, onClick: (e) => {
                var _a, _b;
                (_a = restProps.onClick) === null || _a === void 0 ? void 0 : _a.call(restProps, e);
                (_b = inputRef.current) === null || _b === void 0 ? void 0 : _b.focus({ preventScroll: true });
            } }, { children: [checkNodeExist(dPrefixNode) && _jsx("div", Object.assign({ className: `${dPrefix}input__prefix` }, { children: dPrefixNode })), _jsx(DBaseInput, Object.assign({ dFormControl: dFormControl, dLabelFor: true }, { children: ({ render: renderBaseInput }) => {
                        const input = renderBaseInput(_jsx("input", { ref: combineInputRef, className: `${dPrefix}input__input`, placeholder: dPlaceholder, value: dataRef.current.showValue, type: dType === 'password' ? (password ? 'password' : 'text') : dType, max: dMax, min: dMin, step: dStep, disabled: disabled, onChange: (e) => {
                                dataRef.current.showValue = e.currentTarget.value;
                                forceUpdate();
                                const val = Number(dataRef.current.showValue);
                                if ((!isUndefined(dMax) && val > dMax) ||
                                    (!isUndefined(dMin) && val < dMin) ||
                                    (dInteger && !Number.isInteger(val))) {
                                    return;
                                }
                                changeValue(dataRef.current.showValue);
                            }, onFocus: () => {
                                setIsFocus(true);
                            }, onBlur: () => {
                                if (dType === 'number') {
                                    if (dataRef.current.showValue) {
                                        let val = Number(dataRef.current.showValue);
                                        if (!isUndefined(dMax) && val > dMax) {
                                            val = dMax;
                                        }
                                        if (!isUndefined(dMin) && val < dMin) {
                                            val = dMin;
                                        }
                                        if (dInteger && !Number.isInteger(val)) {
                                            val = Math.round(val);
                                        }
                                        changeValue(val.toString());
                                    }
                                    else {
                                        changeValue('');
                                    }
                                }
                                dataRef.current.showValue = _value;
                                setIsFocus(false);
                            } }));
                        return isUndefined(dInputRender) ? input : dInputRender(input);
                    } })), dClearable && !disabled && (_jsx("div", Object.assign({ className: `${dPrefix}input__clear`, style: { opacity: dataRef.current.showValue.length > 0 ? 1 : 0 }, role: "button", "aria-label": t('Clear'), onClick: () => {
                        changeValue('');
                        onClear === null || onClear === void 0 ? void 0 : onClear();
                    } }, { children: _jsx(CloseCircleFilled, {}) }))), dType === 'password' && !disabled && (_jsx("div", Object.assign({ className: `${dPrefix}input__password`, role: "button", "aria-label": t('Input', password ? 'Password is not visible' : 'Password is visible'), onClick: () => {
                        changePassword((prevPassword) => !prevPassword);
                    } }, { children: password ? _jsx(EyeInvisibleOutlined, {}) : _jsx(EyeOutlined, {}) }))), dType === 'number' && dNumbetButton && !disabled && (_jsxs("div", Object.assign({ className: `${dPrefix}input__number-container` }, { children: [_jsx("div", Object.assign({ className: `${dPrefix}input__number`, role: "button", "aria-label": t('Input', 'Increase number'), onMouseDown: (e) => {
                                if (e.button === 0) {
                                    handleNumberMouseDown();
                                }
                            }, onTouchStart: () => {
                                handleNumberMouseDown();
                            }, onTouchEnd: () => {
                                handleNumberMouseUp();
                            }, onClick: () => {
                                changeNumber();
                            } }, { children: _jsx(DCustomIcon, Object.assign({ viewBox: "0 0 24 24" }, { children: _jsx("path", { d: "M19.637 16.4369C19.0513 17.0227 18.1015 17.0227 17.5157 16.4369L11.8589 10.7801L6.20202 16.4369C5.61623 17.0227 4.66648 17.0227 4.0807 16.4369C3.49491 15.8511 3.49491 14.9014 4.0807 14.3156L10.7982 7.59809C11.384 7.01231 12.3337 7.01231 12.9195 7.59809L19.637 14.3156C20.2228 14.9014 20.2228 15.8511 19.637 16.4369Z" }) })) })), _jsx("div", Object.assign({ className: `${dPrefix}input__number`, role: "button", "aria-label": t('Input', 'Decrease number'), onMouseDown: (e) => {
                                if (e.button === 0) {
                                    handleNumberMouseDown(false);
                                }
                            }, onTouchStart: () => {
                                handleNumberMouseDown(false);
                            }, onTouchEnd: () => {
                                handleNumberMouseUp();
                            }, onClick: () => {
                                changeNumber(false);
                            } }, { children: _jsx(DCustomIcon, Object.assign({ viewBox: "0 0 24 24" }, { children: _jsx("path", { d: "M4.08045 7.59809C4.66624 7.01231 5.61599 7.01231 6.20177 7.59809L11.8586 13.2549L17.5155 7.59809C18.1013 7.01231 19.051 7.01231 19.6368 7.59809C20.2226 8.18388 20.2226 9.13363 19.6368 9.71941L12.9193 16.4369C12.3335 17.0227 11.3838 17.0227 10.798 16.4369L4.08045 9.71941C3.49467 9.13363 3.49467 8.18388 4.08045 7.59809Z" }) })) }))] }))), checkNodeExist(dSuffix) && _jsx("div", Object.assign({ className: `${dPrefix}input__suffix` }, { children: dSuffix }))] }))) })));
}

==> ui-18.1.4.tgz: package/components/input/Input.js <==
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import { isUndefined } from 'lodash';
import { useMemo, useRef, useState } from 'react';
import { Subject, fromEvent, takeUntil, first } from 'rxjs';
import { useAsync, useForceUpdate, useForkRef, useUnmount } from '@react-devui/hooks';
import { CloseCircleFilled, DCustomIcon, EyeInvisibleOutlined, EyeOutlined } from '@react-devui/icons';
import { checkNodeExist, getClassName } from '@react-devui/utils';
import { useGeneralContext, useDValue } from '../../hooks';
import { registerComponentMate } from '../../utils';
import { DBaseDesign } from '../_base-design';
import { DBaseInput } from '../_base-input';
import { useFormControl } from '../form';
import { useComponentConfig, usePrefixConfig, useTranslation } from '../root';
const { COMPONENT_NAME } = registerComponentMate({ COMPONENT_NAME: 'DInput' });
export function DInput(props) {
    const _a = useComponentConfig(COMPONENT_NAME, props), { dRef, dFormControl, dModel, dType, dPrefix: dPrefixNode, dSuffix, dPassword, dNumbetButton = true, dClearable = false, dSize, dMax, dMin, dStep, dInteger = false, dPlaceholder, dDisabled = false, dInputRender, onModelChange, onClear, onPasswordChange } = _a, restProps = __rest(_a, ["dRef", "dFormControl", "dModel", "dType", "dPrefix", "dSuffix", "dPassword", "dNumbetButton", "dClearable", "dSize", "dMax", "dMin", "dStep", "dInteger", "dPlaceholder", "dDisabled", "dInputRender", "onModelChange", "onClear", "onPasswordChange"]);
    //#region Context
    const dPrefix = usePrefixConfig();
    const { gSize, gDisabled } = useGeneralContext();
    //#endregion
    //#region Ref
    const inputRef = useRef(null);
    const combineInputRef = useForkRef(inputRef, dRef === null || dRef === void 0 ? void 0 : dRef.input);
    //#endregion
    const dataRef = useRef({
        showValue: '',
        prevValue: '',
    });
    const async = useAsync();
    const [t] = useTranslation();
    const forceUpdate = useForceUpdate();
    const [password, changePassword] = useDValue(true, dPassword, onPasswordChange);
    const onDestroy$ = useMemo(() => new Subject(), []);
    const formControlInject = useFormControl(dFormControl);
    const [_value, changeValue] = useDValue('', dModel, onModelChange, undefined, formControlInject);
    if (_value !== dataRef.current.prevValue) {
        dataRef.current.showValue = dataRef.current.prevValue = _value;
    }
    const [isFocus, setIsFocus] = useState(false);
    const size = dSize !== null && dSize !== void 0 ? dSize : gSize;
    const disabled = dDisabled || gDisabled || (dFormControl === null || dFormControl === void 0 ? void 0 : dFormControl.control.disabled);
    const changeNumber = (isIncrease = true) => {
        var _a, _b;
        const stepVal = dStep !== null && dStep !== void 0 ? dStep : 1;
        const newVal = (() => {
            let val = Number(dataRef.current.showValue);
            if (Number.isNaN(val)) {
                return 0;
            }
            if (dInteger && !Number.isInteger(val)) {
                val = Math.round(val);
            }
            return isIncrease ? val + stepVal : val - stepVal;
        })();
        changeValue(Math.max(dMin !== null && dMin !== void 0 ? dMin : -Infinity, Math.min(dMax !== null && dMax !== void 0 ? dMax : Infinity, newVal)).toFixed((_b = (_a = stepVal.toString().split('.')[1]) === null || _a === void 0 ? void 0 : _a.length) !== null && _b !== void 0 ? _b : 0));
    };
    const handleNumberMouseUp = () => {
        var _a, _b, _c, _d;
        (_b = (_a = dataRef.current).clearLoop) === null || _b === void 0 ? void 0 : _b.call(_a);
        (_d = (_c = dataRef.current).clearTid) === null || _d === void 0 ? void 0 : _d.call(_c);
    };
    const handleNumberMouseDown = (isIncrease = true) => {
        const loop = () => {
            changeNumber(isIncrease);
            dataRef.current.clearLoop = async.setTimeout(() => loop(), 50);
        };
        dataRef.current.clearTid = async.setTimeout(() => loop(), 400);
        fromEvent(window, 'mouseup')
            .pipe(takeUntil(onDestroy$), first())
            .subscribe({
            next: () => {
                handleNumberMouseUp();
            },
        });
    };
    const preventBlur = (e) => {
        if (e.target !== inputRef.current && e.button === 0) {
            e.preventDefault();
        }
    };
    useUnmount(() => {
        handleNumberMouseUp();
        onDestroy$.next();
        onDestroy$.complete();
    });
    return (_jsx(DBaseDesign, Object.assign({ dComposeDesign: {
            active: isFocus,
            disabled: disabled,
        }, dFormDesign: {
            control: dFormControl,
        } }, { children: ({ render: renderBaseDesign }) => renderBaseDesign(_jsxs("div", Object.assign({}, restProps, { className: getClassName(restProps.className, `${dPrefix}input`, {
                [`${dPrefix}input--${size}`]: size,
                [`${dPrefix}input--button-right`]: dType === 'number' && dNumbetButton && !disabled && !checkNodeExist(dSuffix),
                'is-disabled': disabled,
                'is-focus': isFocus,
            }), onMouseDown: (e) => {
                var _a;
                (_a = restProps.onMouseDown) === null || _a === void 0 ? void 0 : _a.call(restProps, e);
                preventBlur(e);
            }, onMouseUp: (e) => {
                var _a;
                (_a = restProps.onMouseUp) === null || _a === void 0 ? void 0 : _a.call(restProps, e);
                preventBlur(e);
            }, onClick: (e) => {
                var _a, _b;
                (_a = restProps.onClick) === null || _a === void 0 ? void 0 : _a.call(restProps, e);
                (_b = inputRef.current) === null || _b === void 0 ? void 0 : _b.focus({ preventScroll: true });
            } }, { children: [checkNodeExist(dPrefixNode) && _jsx("div", Object.assign({ className: `${dPrefix}input__prefix` }, { children: dPrefixNode })), _jsx(DBaseInput, Object.assign({ dFormControl: dFormControl, dLabelFor: true }, { children: ({ render: renderBaseInput }) => {
                        const input = renderBaseInput(_jsx("input", { ref: combineInputRef, className: `${dPrefix}input__input`, placeholder: dPlaceholder, value: dataRef.current.showValue, type: dType === 'password' ? (password ? 'password' : 'text') : dType, max: dMax, min: dMin, step: dStep, disabled: disabled, onChange: (e) => {
                                dataRef.current.showValue = e.currentTarget.value;
                                forceUpdate();
                                const val = Number(dataRef.current.showValue);
                                if ((!isUndefined(dMax) && val > dMax) ||
                                    (!isUndefined(dMin) && val < dMin) ||
                                    (dInteger && !Number.isInteger(val))) {
                                    return;
                                }
                                changeValue(dataRef.current.showValue);
                            }, onFocus: () => {
                                setIsFocus(true);
                            }, onBlur: () => {
                                if (dType === 'number') {
                                    if (dataRef.current.showValue) {
                                        let val = Number(dataRef.current.showValue);
                                        if (!isUndefined(dMax) && val > dMax) {
                                            val = dMax;
                                        }
                                        if (!isUndefined(dMin) && val < dMin) {
                                            val = dMin;
                                        }
                                        if (dInteger && !Number.isInteger(val)) {
                                            val = Math.round(val);
                                        }
                                        changeValue(val.toString());
                                    }
                                    else {
                                        changeValue('');
                                    }
                                }
                                dataRef.current.showValue = _value;
                                setIsFocus(false);
                            } }));
                        return isUndefined(dInputRender) ? input : dInputRender(input);
                    } })), dClearable && !disabled && (_jsx("div", Object.assign({ className: `${dPrefix}input__clear`, style: { opacity: dataRef.current.showValue.length > 0 ? 1 : 0 }, role: "button", "aria-label": t('Clear'), onClick: () => {
                        changeValue('');
                        onClear === null || onClear === void 0 ? void 0 : onClear();
                    } }, { children: _jsx(CloseCircleFilled, {}) }))), dType === 'password' && !disabled && (_jsx("div", Object.assign({ className: `${dPrefix}input__password`, role: "button", "aria-label": t('Input', password ? 'Password is not visible' : 'Password is visible'), onClick: () => {
                        changePassword((prevPassword) => !prevPassword);
                    } }, { children: password ? _jsx(EyeInvisibleOutlined, {}) : _jsx(EyeOutlined, {}) }))), dType === 'number' && dNumbetButton && !disabled && (_jsxs("div", Object.assign({ className: `${dPrefix}input__number-container` }, { children: [_jsx("div", Object.assign({ className: `${dPrefix}input__number`, role: "button", "aria-label": t('Input', 'Increase number'), onMouseDown: (e) => {
                                if (e.button === 0) {
                                    handleNumberMouseDown();
                                }
                            }, onTouchStart: () => {
                                handleNumberMouseDown();
                            }, onTouchEnd: () => {
                                handleNumberMouseUp();
                            }, onClick: () => {
                                changeNumber();
                            } }, { children: _jsx(DCustomIcon, Object.assign({ viewBox: "0 0 24 24" }, { children: _jsx("path", { d: "M19.637 16.4369C19.0513 17.0227 18.1015 17.0227 17.5157 16.4369L11.8589 10.7801L6.20202 16.4369C5.61623 17.0227 4.66648 17.0227 4.0807 16.4369C3.49491 15.8511 3.49491 14.9014 4.0807 14.3156L10.7982 7.59809C11.384 7.01231 12.3337 7.01231 12.9195 7.59809L19.637 14.3156C20.2228 14.9014 20.2228 15.8511 19.637 16.4369Z" }) })) })), _jsx("div", Object.assign({ className: `${dPrefix}input__number`, role: "button", "aria-label": t('Input', 'Decrease number'), onMouseDown: (e) => {
                                if (e.button === 0) {
                                    handleNumberMouseDown(false);
                                }
                            }, onTouchStart: () => {
                                handleNumberMouseDown(false);
                            }, onTouchEnd: () => {
                                handleNumberMouseUp();
                            }, onClick: () => {
                                changeNumber(false);
                            } }, { children: _jsx(DCustomIcon, Object.assign({ viewBox: "0 0 24 24" }, { children: _jsx("path", { d: "M4.08045 7.59809C4.66624 7.01231 5.61599 7.01231 6.20177 7.59809L11.8586 13.2549L17.5155 7.59809C18.1013 7.01231 19.051 7.01231 19.6368 7.59809C20.2226 8.18388 20.2226 9.13363 19.6368 9.71941L12.9193 16.4369C12.3335 17.0227 11.3838 17.0227 10.798 16.4369L4.08045 9.71941C3.49467 9.13363 3.49467 8.18388 4.08045 7.59809Z" }) })) }))] }))), checkNodeExist(dSuffix) && _jsx("div", Object.assign({ className: `${dPrefix}input__suffix` }, { children: dSuffix }))] }))) })));
}
